==> jc-1.4.0.tar.gz: polyglot/util/NestedMap__24KeySet.h <==
// public final class polyglot.util.NestedMap$KeySet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class 8292a88a90dd0442 polyglot_util_NestedMap__24KeySet

// header file dependencies
// @dep_header java_util_AbstractSet

#include "java/util/AbstractSet.h"

#ifndef _JC_polyglot_util_NestedMap__24KeySet_H_
#define _JC_polyglot_util_NestedMap__24KeySet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;
struct _jc_polyglot_util_NestedMap$object;

// Typedefs
typedef struct _jc_polyglot_util_NestedMap__24KeySet$sub_refs	_jc_polyglot_util_NestedMap__24KeySet$sub_refs;
typedef struct _jc_polyglot_util_NestedMap__24KeySet$sub_nonrefs	_jc_polyglot_util_NestedMap__24KeySet$sub_nonrefs;
typedef struct _jc_polyglot_util_NestedMap__24KeySet$refs	_jc_polyglot_util_NestedMap__24KeySet$refs;
typedef struct _jc_polyglot_util_NestedMap__24KeySet$nonrefs	_jc_polyglot_util_NestedMap__24KeySet$nonrefs;
typedef struct _jc_polyglot_util_NestedMap__24KeySet$object	_jc_polyglot_util_NestedMap__24KeySet$object;

typedef const struct _jc_polyglot_util_NestedMap__24KeySet$vmethods	_jc_polyglot_util_NestedMap__24KeySet$vmethods;
typedef const struct _jc_polyglot_util_NestedMap__24KeySet$vtable	_jc_polyglot_util_NestedMap__24KeySet$vtable;
typedef const struct _jc_polyglot_util_NestedMap__24KeySet$vtype	_jc_polyglot_util_NestedMap__24KeySet$vtype;

// Constructors
extern void _jc_polyglot_util_NestedMap__24KeySet$method$_init$e86507e3abc60b21(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *, struct _jc_polyglot_util_NestedMap$object *);

// Virtual methods
extern jboolean _jc_polyglot_util_NestedMap__24KeySet$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_polyglot_util_NestedMap__24KeySet$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *);
extern jboolean _jc_polyglot_util_NestedMap__24KeySet$method$remove$d21babbbb7fafe72(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_polyglot_util_NestedMap__24KeySet$method$size$345df5220fc60ade(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_NestedMap__24KeySet$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_polyglot_util_NestedMap__24KeySet$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_polyglot_util_NestedMap__24KeySet$method_info$remove$d21babbbb7fafe72;
extern _jc_method _jc_polyglot_util_NestedMap__24KeySet$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_polyglot_util_NestedMap__24KeySet$vmethods {
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *);
	jboolean	(*remove$d21babbbb7fafe72)(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *, struct _jc_java_lang_Object$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *);
};

// Vtable
struct _jc_polyglot_util_NestedMap__24KeySet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_polyglot_util_NestedMap__24KeySet$vmethods	polyglot_util_NestedMap__24KeySet;
};

// Vtype
struct _jc_polyglot_util_NestedMap__24KeySet$vtype {
	_jc_type			type;
	_jc_polyglot_util_NestedMap__24KeySet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_NestedMap__24KeySet$sub_refs {
	struct _jc_polyglot_util_NestedMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_util_NestedMap__24KeySet$refs {
    _jc_polyglot_util_NestedMap__24KeySet$sub_refs	polyglot_util_NestedMap__24KeySet;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_NestedMap__24KeySet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_NestedMap__24KeySet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_polyglot_util_NestedMap__24KeySet$sub_nonrefs	polyglot_util_NestedMap__24KeySet;
};

// Object instance structure
struct _jc_polyglot_util_NestedMap__24KeySet$object {
	_jc_polyglot_util_NestedMap__24KeySet$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_NestedMap__24KeySet$vtype	*vtype;
	_jc_polyglot_util_NestedMap__24KeySet$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_NestedMap__24KeySet$vtype _jc_polyglot_util_NestedMap__24KeySet$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_NestedMap__24KeySet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_NestedMap__24KeySet$class_object;

#endif	/* _JC_polyglot_util_NestedMap__24KeySet_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/NestedMap__24KeySet.h <==
// public final class polyglot.util.NestedMap$KeySet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class 8292a88a90dd0442 polyglot_util_NestedMap__24KeySet

// header file dependencies
// @dep_header java_util_AbstractSet

#include "java/util/AbstractSet.h"

#ifndef _JC_polyglot_util_NestedMap__24KeySet_H_
#define _JC_polyglot_util_NestedMap__24KeySet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;
struct _jc_polyglot_util_NestedMap$object;

// Typedefs
typedef struct _jc_polyglot_util_NestedMap__24KeySet$sub_refs	_jc_polyglot_util_NestedMap__24KeySet$sub_refs;
typedef struct _jc_polyglot_util_NestedMap__24KeySet$sub_nonrefs	_jc_polyglot_util_NestedMap__24KeySet$sub_nonrefs;
typedef struct _jc_polyglot_util_NestedMap__24KeySet$refs	_jc_polyglot_util_NestedMap__24KeySet$refs;
typedef struct _jc_polyglot_util_NestedMap__24KeySet$nonrefs	_jc_polyglot_util_NestedMap__24KeySet$nonrefs;
typedef struct _jc_polyglot_util_NestedMap__24KeySet$object	_jc_polyglot_util_NestedMap__24KeySet$object;

typedef const struct _jc_polyglot_util_NestedMap__24KeySet$vmethods	_jc_polyglot_util_NestedMap__24KeySet$vmethods;
typedef const struct _jc_polyglot_util_NestedMap__24KeySet$vtable	_jc_polyglot_util_NestedMap__24KeySet$vtable;
typedef const struct _jc_polyglot_util_NestedMap__24KeySet$vtype	_jc_polyglot_util_NestedMap__24KeySet$vtype;

// Constructors
extern void _jc_polyglot_util_NestedMap__24KeySet$method$_init$e86507e3abc60b21(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *, struct _jc_polyglot_util_NestedMap$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_util_NestedMap__24KeySet$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_util_NestedMap__24KeySet$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_util_NestedMap__24KeySet$method$remove$d21babbbb7fafe72(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_util_NestedMap__24KeySet$method$size$345df5220fc60ade(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_NestedMap__24KeySet$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_polyglot_util_NestedMap__24KeySet$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_polyglot_util_NestedMap__24KeySet$method_info$remove$d21babbbb7fafe72;
extern _jc_method _jc_polyglot_util_NestedMap__24KeySet$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_polyglot_util_NestedMap__24KeySet$vmethods {
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *) _JC_JCNI_ATTR;
	jboolean	(*remove$d21babbbb7fafe72)(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_polyglot_util_NestedMap__24KeySet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_NestedMap__24KeySet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_polyglot_util_NestedMap__24KeySet$vmethods	polyglot_util_NestedMap__24KeySet;
};

// Vtype
struct _jc_polyglot_util_NestedMap__24KeySet$vtype {
	_jc_type			type;
	_jc_polyglot_util_NestedMap__24KeySet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_NestedMap__24KeySet$sub_refs {
	struct _jc_polyglot_util_NestedMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_util_NestedMap__24KeySet$refs {
    _jc_polyglot_util_NestedMap__24KeySet$sub_refs	polyglot_util_NestedMap__24KeySet;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_NestedMap__24KeySet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_NestedMap__24KeySet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_polyglot_util_NestedMap__24KeySet$sub_nonrefs	polyglot_util_NestedMap__24KeySet;
};

// Object instance structure
struct _jc_polyglot_util_NestedMap__24KeySet$object {
	_jc_polyglot_util_NestedMap__24KeySet$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_NestedMap__24KeySet$vtype	*vtype;
	_jc_polyglot_util_NestedMap__24KeySet$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_NestedMap__24KeySet$vtype _jc_polyglot_util_NestedMap__24KeySet$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_NestedMap__24KeySet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_NestedMap__24KeySet$class_object;

#endif	/* _JC_polyglot_util_NestedMap__24KeySet_H_ */
